# gpx2mesh

This project uses [uv](https://docs.astral.sh/uv/getting-started/installation/)
to manage its dependencies. Run the following to install a matching Python
version and project dependencies :

```bash
# Install a version of Python matching the one declared in .python-version
uv python install

# Install project dependencies
uv sync --all-groups
```
